#!/bin/sh
#set -x

echo "S51" > /proc/gpio

FW_PATH="/var/tmp/fw"
FW_BIN="$FW_PATH"/fw.bin
FW_BOOT="$FW_PATH"/boot.bin

UpgradeComplite=0
UpgradeError=1
UpgradeInProgress=2

chmod 777 "$FW_PATH"/upgrade-bin

UPGRADE_OPTS=""

version=$(cat /etc/build)
major=$(echo $version|cut -d'.' -f 1)
minor=$(echo $version|cut -d'.' -f 2)

if [ $major -eq 1 ]; then
    if [ $minor -le 8 ]; then
        if [ -f "$FW_BOOT" ]; then
            md5_cur=$(busybox md5sum "$FW_PATH"/boot.bin | cut -d' ' -f 1)
            md5_img=$(cat "$FW_PATH"/boot.bin.md5)
            if [ "$md5_cur" != "$md5_img" ]; then
                echo "UPGRADE FAIL: Incorrect boot CRC"
                echo "S50" > /proc/gpio
                exit 3
            fi
            UPGRADE_OPTS="$UPGRADE_OPTS -b $FW_BOOT"
        fi
    fi
fi

if [ -f $FW_BIN ]; then
    md5_cur=$(busybox md5sum "$FW_PATH"/fw.bin | cut -d' ' -f 1)
    md5_img=$(cat "$FW_PATH"/fw.md5)
    if [ "$md5_cur" != "$md5_img" ]; then
        echo "UPGRADE FAIL: Incorrect fw CRC"
	echo "S50" > /proc/gpio
        exit 4
    fi
	UPGRADE_OPTS="$UPGRADE_OPTS -f $FW_BIN"
fi

echo "Upgrade firmware started"

"$FW_PATH"/upgrade-bin $UPGRADE_OPTS
RETVAL=$?

if [ "$RETVAL" != "$UpgradeComplite" ]; then
    if [ "$RETVAL" = "$UpgradeInProgress" ]; then
        echo "UPGRADE FAIL: upgrade process is already in progress"
        exit 5
    fi
    echo "UPGRADE FAIL: Error at read/write operation ($RETVAL != $UpgradeComplite)"
    echo "S50" > /proc/gpio
    exit 6
fi

ver_img=$(cat "$FW_PATH"/version)
ln -s "$FW_PATH"/upgrade-bin "$FW_PATH"/board_info
"$FW_PATH"/board_info -w "$ver_img"
"$FW_PATH"/board_info -d "$md5_img"

# fix for zway data partition
ln -s "$FW_PATH"/upgrade-bin "$FW_PATH"/mtd_update
"$FW_PATH"/mtd_update -f "$version" -i "$ver_img"

echo "UPGRADE SUCCESSFULL"

# for old rom compatibility
if [ $? != "0" ]; then
    reboot
    if [ $? != "0" ]; then
        killall -9 timelycheck watchdog
    fi
fi

echo "S50" > /proc/gpio
exit $UpgradeComplite
